pub struct Sample<Api: Api = Default>(/* private fields */);Implementations
Sourceimpl<Api: Default + Api> Sample<Api>
impl<Api: Default + Api> Sample<Api>
Sourcepub fn new_with_size(bytes: c_int) -> Result<Self, Error>
pub fn new_with_size(bytes: c_int) -> Result<Self, Error>
Allocates and returns a new Sample with a buffer large enough to load a file of length bytes.
Equivalent to sys::ffi::playdate_sound_sample::newSampleBuffer
Sourcepub fn new_for_file<P: AsRef<Path>>(path: P) -> Result<Self, ApiError>
pub fn new_for_file<P: AsRef<Path>>(path: P) -> Result<Self, ApiError>
Retrieves size of file and allocate with that size.
Does not load a file.
Sourcepub fn new_from_file<P: AsRef<Path>>(path: P) -> Result<Self, ApiError>
pub fn new_from_file<P: AsRef<Path>>(path: P) -> Result<Self, ApiError>
Loads the file into the self.
Equivalent to sys::ffi::playdate_sound_sample::load
Sourcepub fn new_from_data<'t>(
data: &'t mut [u8],
format: SoundFormat,
sample_rate: u32,
) -> Result<SampleWithData<'t, Api>, Error>
pub fn new_from_data<'t>( data: &'t mut [u8], format: SoundFormat, sample_rate: u32, ) -> Result<SampleWithData<'t, Api>, Error>
Returns a new Sample referencing the given audio data.
The sample keeps a reference to the data instead of copying it,
so the data must remain valid while the sample is active.
Equivalent to sys::ffi::playdate_sound_sample::newSampleFromData
Sourceimpl<Api: Api> Sample<Api>
impl<Api: Api> Sample<Api>
Sourcepub fn new_with_size_with(api: Api, bytes: c_int) -> Result<Self, Error>
pub fn new_with_size_with(api: Api, bytes: c_int) -> Result<Self, Error>
Allocates and returns a new Sample with a buffer large enough to load a file of length bytes.
Equivalent to sys::ffi::playdate_sound_sample::newSampleBuffer
Sourcepub fn new_for_file_with<P: AsRef<Path>>(
api: Api,
path: P,
) -> Result<Self, ApiError>
pub fn new_for_file_with<P: AsRef<Path>>( api: Api, path: P, ) -> Result<Self, ApiError>
Retrieves size of file and allocate with that size.
Does not load a file.
Sourcepub fn new_from_file_with<P: AsRef<Path>>(
api: Api,
path: P,
) -> Result<Self, ApiError>
pub fn new_from_file_with<P: AsRef<Path>>( api: Api, path: P, ) -> Result<Self, ApiError>
Loads the file into the self.
Equivalent to sys::ffi::playdate_sound_sample::load
Sourcepub fn new_from_data_with<'t>(
api: Api,
data: &'t mut [u8],
format: SoundFormat,
sample_rate: u32,
) -> Result<SampleWithData<'t, Api>, Error>
pub fn new_from_data_with<'t>( api: Api, data: &'t mut [u8], format: SoundFormat, sample_rate: u32, ) -> Result<SampleWithData<'t, Api>, Error>
Returns a new Sample referencing the given audio data.
The sample keeps a reference to the data instead of copying it,
so the data must remain valid while the sample is active.
Equivalent to sys::ffi::playdate_sound_sample::newSampleFromData
Sourceimpl<Api: Api> Sample<Api>
impl<Api: Api> Sample<Api>
Sourcepub fn length(&self) -> c_float
pub fn length(&self) -> c_float
Returns the length, in seconds.
Equivalent to sys::ffi::playdate_sound_sample::getLength
Sourcepub fn get_data<'t>(&'t self) -> SampleData<'t>
pub fn get_data<'t>(&'t self) -> SampleData<'t>
Equivalent to sys::ffi::playdate_sound_sample::getData